@@ -158,13 +158,7 @@ void GetExtInfos(void)
    bGLExt=TRUE;
   }
 
- if(iUseExts &&                                        // extension support wanted?
-    (strstr((char *)glGetString(GL_EXTENSIONS),
-     "GL_EXT_texture_edge_clamp") ||
-     strstr((char *)glGetString(GL_EXTENSIONS),        // -> check clamp support, if yes: use it
-     "GL_SGIS_texture_edge_clamp")))
-      iClampType=GL_TO_EDGE_CLAMP;
- else iClampType=GL_CLAMP;
+ iClampType=GL_CLAMP_TO_EDGE ;
 
  glColorTableEXTEx=(PFNGLCOLORTABLEEXT)NULL;           // init ogl palette func pointer
 
@@ -272,7 +266,7 @@ void SetExtGLFuncs(void)
     giWantedTYPE=GL_UNSIGNED_BYTE;
     break;
    //--------------------------------------------------// 
-   case 1:                                             // -> R4G4B4A4
+  /* case 1:                                             // -> R4G4B4A4
     if(bGLExt)
      {
       giWantedRGBA=GL_RGBA4;
@@ -380,6 +374,7 @@ void SetExtGLFuncs(void)
 
     break;
    //--------------------------------------------------// 
+   */
   }
 
  bBlendEnable=FALSE;                                   // init blending: off
@@ -410,7 +405,8 @@ GLubyte texscan[4][16]=
 
 void CreateScanLines(void)
 {
- if(iUseScanLines)
+// to review
+ /*if(iUseScanLines)
   {
    int y;
    if(iScanBlend<0)                                    // special scan mask mode
@@ -440,7 +436,8 @@ void CreateScanLines(void)
       }
      glEndList();
     }
-  }
+  //}
+  */
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -465,9 +462,10 @@ int GLinitialize()
 
  glMatrixMode(GL_PROJECTION);                          // init projection with psx resolution
  glLoadIdentity();
- glOrtho(0,PSXDisplay.DisplayMode.x,
+ glOrthof(0,PSXDisplay.DisplayMode.x,
          PSXDisplay.DisplayMode.y, 0, -1, 1);
 
+
  if(iZBufferDepth)                                     // zbuffer?
   {
    uiBufferBits=GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT;
@@ -483,30 +481,32 @@ int GLinitialize()
 
  glClearColor(0.0f, 0.0f, 0.0f, 0.0f);                 // first buffer clear
  glClear(uiBufferBits);
-
- if(bUseLines)                                         // funny lines 
-  {
-   glPolygonMode(GL_FRONT, GL_LINE); 
-   glPolygonMode(GL_BACK, GL_LINE); 
-  }
- else                                                  // or the real filled thing
+// to review !
+// ===============================================================================================================================================================
+//
+ /*if(bUseLines)                                         // funny lines 
+  */{
+ //  glPolygonMode(GL_FRONT, GL_LINE); 
+ //  glPolygonMode(GL_BACK, GL_LINE); 
+  }/*
+ else                                                // or the real filled thing
   {
    glPolygonMode(GL_FRONT, GL_FILL);
    glPolygonMode(GL_BACK, GL_FILL);
-  }
+  }*/
 
- MakeDisplayLists();                                   // lists for menu/opaque
+// MakeDisplayLists();                                   // lists for menu/opaque
  GetExtInfos();                                        // get ext infos
  SetExtGLFuncs();                                      // init all kind of stuff (tex function pointers)
  
  glEnable(GL_ALPHA_TEST);                              // wanna alpha test
 
- if(!bUseAntiAlias)                                    // no anti-alias (default)
-  {
+ /*if(!bUseAntiAlias)                                    // no anti-alias (default)
+  {*/
    glDisable(GL_LINE_SMOOTH);
-   glDisable(GL_POLYGON_SMOOTH);
+  // glDisable(GL_POLYGON_SMOOTH);
    glDisable(GL_POINT_SMOOTH);
-  }
+  /*}
  else                                                  // wanna try it? glitches galore...
   {                    
    glHint(GL_PERSPECTIVE_CORRECTION_HINT,GL_NICEST);
@@ -516,7 +516,7 @@ int GLinitialize()
    glHint(GL_LINE_SMOOTH_HINT,GL_NICEST);
    glHint(GL_POINT_SMOOTH_HINT,GL_NICEST);
    glHint(GL_POLYGON_SMOOTH_HINT,GL_NICEST);
-  }
+  }*/
 
  ubGloAlpha=127;                                       // init some drawing vars
  ubGloColAlpha=127;
@@ -531,20 +531,23 @@ int GLinitialize()
 
  glDisable(GL_FOG);                                    // turn all (currently) unused modes off
  glDisable(GL_LIGHTING);  
- glDisable(GL_LOGIC_OP);
+ // to review !
+ //glDisable(GL_LOGIC_OP);
  glDisable(GL_STENCIL_TEST);  
- glDisable(GL_TEXTURE_1D);
+ // to review !
+ //glDisable(GL_TEXTURE_1D);
  glDisable(GL_TEXTURE_2D);
  glDisable(GL_CULL_FACE);
 
- glPixelTransferi(GL_RED_SCALE, 1);                    // to be sure:
+ // to review !
+ /*glPixelTransferi(GL_RED_SCALE, 1);                    // to be sure:
  glPixelTransferi(GL_RED_BIAS, 0);                     // init more OGL vals
  glPixelTransferi(GL_GREEN_SCALE, 1);
  glPixelTransferi(GL_GREEN_BIAS, 0);
  glPixelTransferi(GL_BLUE_SCALE, 1);
  glPixelTransferi(GL_BLUE_BIAS, 0);
  glPixelTransferi(GL_ALPHA_SCALE, 1);
- glPixelTransferi(GL_ALPHA_BIAS, 0);                                                  
+ glPixelTransferi(GL_ALPHA_BIAS, 0);   */                                               
 
  printf((const char*)glGetString(GL_VENDOR));                       // linux: tell user what is getting used
  printf("\n");
@@ -564,7 +567,7 @@ int GLinitialize()
   {
    ulKeybits|=KEY_SHOWFPS;                             // -> ok, turn display on
    szDispBuf[0]=0;
-   BuildDispMenu(0);
+ //  BuildDispMenu(0);
   }
  
  bIsFirstFrame = FALSE;                                // we have survived the first frame :)
@@ -578,9 +581,10 @@ int GLinitialize()
 
 void GLcleanup() 
 {                                                     
- KillDisplayLists();                                   // bye display lists
+ //KillDisplayLists();                                   // bye display lists
 
- if(iUseScanLines)                                     // scanlines used?
+ // to review !
+ /*if(iUseScanLines)                                     // scanlines used?
   {
    if(iScanBlend<0)
     {
@@ -589,7 +593,7 @@ void GLcleanup()
      gTexScanName=0;
     }
    else glDeleteLists(uiScanLine,1);                   // otherwise del scanline display list
-  }
+  }*/
 
  CleanupTextureStore();                                // bye textures
 }
