@@ -498,6 +498,7 @@ static Cursor        cursor;
 static XVisualInfo   *myvisual;
 static Colormap      colormap;
 static Window        window;
+EGLSurface  iEglSurface;
 
 static int bModeChanged=0;
 
@@ -510,9 +511,9 @@ typedef struct
   long input_mode;
 } MotifWmHints;
 
-static int dbdepat[]={GLX_RGBA,GLX_DOUBLEBUFFER,GLX_DEPTH_SIZE,16,None};
-static int dbnodepat[]={GLX_RGBA,GLX_DOUBLEBUFFER,None};
-static GLXContext cx;
+//static int dbdepat[]={GL_RGBA,GL_DEPTH_SIZE,16,None};
+//static int dbnodepat[]={GL_RGBA,None};
+EGLContext cx;
 
 static int fx=0;
 
@@ -522,7 +523,10 @@ void osd_close_display (void)                          // close display
 {
  if(display)                                           // display exists?
   {
-   glXDestroyContext(display,cx);                      // -> kill context
+  
+
+ eglDestroyContext (display,cx);
+ eglTerminate (display);
    XFreeColormap(display, colormap);                   // -> kill colormap
    XSync(display,False);                               // -> sync events
 
@@ -564,7 +568,7 @@ void sysdep_create_display(void)                       // create display
      putenv(gammastr);
     }
   }
-
+/*
  display=XOpenDisplay(NULL);                           // open display
  if(!display)                                          // no display?
   {
@@ -623,7 +627,34 @@ void sysdep_create_display(void)                       // create display
  if(iZBufferDepth)                                      // visual (with or without zbuffer)
       myvisual=glXChooseVisual(display,myscreen,dbdepat);
  else myvisual=glXChooseVisual(display,myscreen,dbnodepat);
+*/
 
+	display = XOpenDisplay( 0 );
+
+	myscreen = XDefaultScreen( display );
+	
+	// Gets the window parameters
+	//sRootWindow = RootWindow(display, myscreen);
+	iColDepth = DefaultDepth(display, myscreen);
+	myvisual = new XVisualInfo;
+	XMatchVisualInfo( display, myscreen, iColDepth, TrueColor, myvisual);
+
+
+	
+	XMapWindow(display, window);
+	XFlush(display);
+
+	/*
+		Step 1 - Get the default display.
+		EGL uses the concept of a "display" which in most environments
+		corresponds to a single physical screen. Since we usually want
+		to draw to the main screen or only have a single screen to begin
+		with, we let EGL pick the default display.
+		Querying other displays is platform specific.
+	*/
+
+	
+// =========
  if(!myvisual)                                         // no visual?
   {
    fprintf(stderr,"Failed to obtain visual!!!\n");     // -> bye
@@ -631,7 +662,25 @@ void sysdep_create_display(void)                       // create display
    return;
   }
 
- cx=glXCreateContext(display,myvisual,0,GL_TRUE);      // create rendering context
+  EGLConfig   iEglConfig;  
+  EGLint numConfigs;
+ 
+ EGLint attribList [] = 
+{ 
+	EGL_BUFFER_SIZE, 0,  // color depth
+	EGL_DEPTH_SIZE, 15,  // z-buffer
+	EGL_NONE 
+};	
+ 
+
+
+		attribList [1] = 16; 
+
+
+eglChooseConfig (display, attribList, &iEglConfig, 1, &numConfigs);
+	 
+	 
+ cx=(EGLint*)eglCreateContext(display, iEglConfig, EGL_NO_CONTEXT, 0);    // create rendering context
 
  if(!cx)                                               // no context?
   {
@@ -748,7 +797,9 @@ void sysdep_create_display(void)                       // create display
  XMapRaised(display,window);
  XClearWindow(display,window);
  XWindowEvent(display,window,ExposureMask,&event);
- glXMakeCurrent(display,window,cx);
+
+ 
+ eglMakeCurrent (display, iEglSurface, iEglSurface, cx);
 
  printf((const char *)glGetString(GL_VENDOR));
  printf("\n");
@@ -866,6 +917,8 @@ void PaintBlackBorders(void)
  if(bBlendEnable)     {glDisable(GL_BLEND);bBlendEnable=FALSE;}
  glDisable(GL_ALPHA_TEST);
 
+ // to review !
+ /*
  glBegin(GL_QUADS);
 
  vertex[0].c.lcol=0xff000000;
@@ -897,6 +950,8 @@ void PaintBlackBorders(void)
   }
 
  glEnd();
+ 
+ */
 
  glEnable(GL_ALPHA_TEST);
  glEnable(GL_SCISSOR_TEST);
@@ -909,7 +964,8 @@ void PaintBlackBorders(void)
 __inline void XPRIMdrawTexturedQuad(OGLVertex* vertex1, OGLVertex* vertex2, 
                                     OGLVertex* vertex3, OGLVertex* vertex4) 
 {
-
+// to review !
+/*
  glBegin(GL_QUAD_STRIP);
   glTexCoord2fv(&vertex1->sow);
   glVertex3fv(&vertex1->x);
@@ -923,6 +979,7 @@ __inline void XPRIMdrawTexturedQuad(OGLVertex* vertex1, OGLVertex* vertex2,
   glTexCoord2fv(&vertex3->sow);
   glVertex3fv(&vertex3->x);
  glEnd();
+ */
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -931,8 +988,11 @@ __inline void XPRIMdrawTexturedQuad(OGLVertex* vertex1, OGLVertex* vertex2,
 
 void SetScanLines(void)
 {
+
+// to review !
+/*
  glLoadIdentity();
- glOrtho(0,iResX,iResY, 0, -1, 1);
+ glOrthof(0,iResX,iResY, 0, -1, 1);
 
  if(bKeepRatio)
   glViewport(0,0,iResX,iResY);
@@ -941,6 +1001,7 @@ void SetScanLines(void)
  glDisable(GL_ALPHA_TEST);
  if(bOldSmoothShaded) {glShadeModel(GL_FLAT);bOldSmoothShaded=FALSE;}
 
+
  if(iScanBlend<0)                                      // special texture mask scanline mode
   {
    if(!bTexEnabled)    {glEnable(GL_TEXTURE_2D);bTexEnabled=TRUE;}
@@ -1004,7 +1065,7 @@ void SetScanLines(void)
   }
 
  glLoadIdentity();
- glOrtho(0,PSXDisplay.DisplayMode.x,
+ glOrthof(0,PSXDisplay.DisplayMode.x,
          PSXDisplay.DisplayMode.y, 0, -1, 1);
 
  if(bKeepRatio)
@@ -1014,7 +1075,8 @@ void SetScanLines(void)
              rRatioRect.bottom);                         // init viewport
 
  glEnable(GL_ALPHA_TEST);
- glEnable(GL_SCISSOR_TEST);                       
+ glEnable(GL_SCISSOR_TEST); 
+*/
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1023,6 +1085,8 @@ void SetScanLines(void)
 
 void BlurBackBuffer(void)
 {
+// to review !
+/*
  if(!gTexBlurName) return;
 
  if(bKeepRatio) glViewport(0,0,iResX,iResY);
@@ -1084,7 +1148,8 @@ void BlurBackBuffer(void)
   glViewport(rRatioRect.left,                            // re-init viewport
              iResY-(rRatioRect.top+rRatioRect.bottom),
              rRatioRect.right, 
-             rRatioRect.bottom);            
+             rRatioRect.bottom); 
+			 */         
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1092,6 +1157,8 @@ void BlurBackBuffer(void)
 
 void UnBlurBackBuffer(void)
 {
+// to review !
+/*
  if(!gTexBlurName) return;
 
  if(bKeepRatio) glViewport(0,0,iResX,iResY);
@@ -1145,6 +1212,7 @@ void UnBlurBackBuffer(void)
              iResY-(rRatioRect.top+rRatioRect.bottom),
              rRatioRect.right, 
              rRatioRect.bottom);                         // init viewport
+			 */
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1220,7 +1288,7 @@ void updateDisplay(void)                               // UPDATE DISPLAY
 
  if(iUseScanLines) SetScanLines();                     // "scan lines" activated? do it
 
- if(usCursorActive) ShowGunCursor();                   // "gun cursor" wanted? show 'em
+ //if(usCursorActive) ShowGunCursor();                   // "gun cursor" wanted? show 'em
 
  if(dwActFixes&128)                                    // special FPS limitation mode?
   {
@@ -1229,15 +1297,15 @@ void updateDisplay(void)                               // UPDATE DISPLAY
     PCcalcfps();         
   }
 
- if(gTexPicName) DisplayPic();                         // some gpu info picture active? display it
+ //if(gTexPicName) DisplayPic();                         // some gpu info picture active? display it
 
  if(bSnapShot) DoSnapShot();                           // snapshot key pressed? cheeeese :)
 
- if(ulKeybits&KEY_SHOWFPS)                             // wanna see FPS?
+ /*if(ulKeybits&KEY_SHOWFPS)                             // wanna see FPS?
   {
    sprintf(szDispBuf,"%06.1f",fps_cur);
    DisplayText();                                      // -> show it
-  }
+  }*/
 
  //----------------------------------------------------//
  // main buffer swapping (well, or skip it)
@@ -1247,7 +1315,7 @@ void updateDisplay(void)                               // UPDATE DISPLAY
    if(!bSkipNextFrame) 
     {
      if(iDrawnSomething)
-      glXSwapBuffers(display,window);
+      eglSwapBuffers(display,iEglSurface);
     }
    if(dwActFixes&0x180)                                // -> special old frame skipping: skip max one in a row
     {
@@ -1260,7 +1328,7 @@ void updateDisplay(void)                               // UPDATE DISPLAY
  else                                                  // no skip ?
   {
    if(iDrawnSomething)
-    glXSwapBuffers(display,window);
+    eglSwapBuffers(display,iEglSurface);
   }
 
  iDrawnSomething=0;
@@ -1358,22 +1426,22 @@ void updateFrontDisplay(void)
     PreviousPSXDisplay.Range.y0)
   PaintBlackBorders();
 
- if(iBlurBuffer) BlurBackBuffer();
+ //if(iBlurBuffer) BlurBackBuffer();
 
- if(iUseScanLines) SetScanLines();
+ //if(iUseScanLines) SetScanLines();
 
- if(usCursorActive) ShowGunCursor();
+ //if(usCursorActive) ShowGunCursor();
 
  bFakeFrontBuffer=FALSE;
  bRenderFrontBuffer=FALSE;
 
- if(gTexPicName) DisplayPic();
- if(ulKeybits&KEY_SHOWFPS) DisplayText();
+ //if(gTexPicName) DisplayPic();
+// if(ulKeybits&KEY_SHOWFPS) DisplayText();
 
  if(iDrawnSomething)                                   // linux:
-  glXSwapBuffers(display,window);
+  eglSwapBuffers(display,iEglSurface);
 
- if(iBlurBuffer) UnBlurBackBuffer();
+ //if(iBlurBuffer) UnBlurBackBuffer();
 }
                                              
 ////////////////////////////////////////////////////////////////////////
@@ -1539,7 +1607,7 @@ void updateDisplayIfChanged(void)
  else                                                  // some res change?
   {
    glLoadIdentity();
-   glOrtho(0,PSXDisplay.DisplayModeNew.x,              // -> new psx resolution
+   glOrthof(0,PSXDisplay.DisplayModeNew.x,              // -> new psx resolution
              PSXDisplay.DisplayModeNew.y, 0, -1, 1);
    if(bKeepRatio) SetAspectRatio();
   }
@@ -1637,10 +1705,11 @@ BOOL bSwapCheck(void)
 
 void CALLBACK GPUcursor(int iPlayer,int x,int y)
 {
+/*
  if(iPlayer<0) return;
  if(iPlayer>7) return;
 
- usCursorActive|=(1<<iPlayer);
+ //usCursorActive|=(1<<iPlayer);
 
  if(x<0)              x=0;
  if(x>iGPUHeightMask) x=iGPUHeightMask;
@@ -1649,6 +1718,7 @@ void CALLBACK GPUcursor(int iPlayer,int x,int y)
 
  ptCursorPoint[iPlayer].x=x;
  ptCursorPoint[iPlayer].y=y;
+ */
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -2152,11 +2222,13 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
 
  ps=pGfxCardScreen;
  
- if(!sArea) glReadBuffer(GL_FRONT);
+ // to review !
+ //if(!sArea) glReadBuffer(GL_FRONT);
 
  glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps);
-               
- if(!sArea) glReadBuffer(GL_BACK);
+     
+// to review !	 
+ //if(!sArea) glReadBuffer(GL_BACK);
 
  s=0;
 
@@ -2300,11 +2372,13 @@ void CheckVRamRead(int x, int y, int dx, int dy,BOOL bFront)
 
  ps=pGfxCardScreen;
  
- if(bFront) glReadBuffer(GL_FRONT);
+ // to review !
+ //if(bFront) glReadBuffer(GL_FRONT);
 
  glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps);
-               
- if(bFront) glReadBuffer(GL_BACK);
+    
+// to review !	
+ //if(bFront) glReadBuffer(GL_BACK);
 
  XS=(float)dx/(float)(udx);
  YS=(float)dy/(float)(udy+1);
@@ -3055,6 +3129,8 @@ void PaintPicDot(unsigned char * p,unsigned char c)
 
 void CALLBACK GPUgetScreenPic(unsigned char * pMem)
 {
+// to review !
+/*
  float XS,YS;int x,y,v;
  unsigned char * ps, * px, * pf;
  unsigned char c;
@@ -3072,6 +3148,9 @@ void CALLBACK GPUgetScreenPic(unsigned char * pMem)
  glReadPixels(0,0,iResX,iResY,GL_RGB,GL_UNSIGNED_BYTE,ps);
                
  glReadBuffer(GL_BACK);
+ 
+ 
+ 
 
  XS=(float)iResX/128;
  YS=(float)iResY/96;
@@ -3088,6 +3167,7 @@ void CALLBACK GPUgetScreenPic(unsigned char * pMem)
      *(pf+2)=*(px+0);
      pf+=3;
     }
+	
   }
 
  /////////////////////////////////////////////////////////////////////
@@ -3127,16 +3207,16 @@ void CALLBACK GPUgetScreenPic(unsigned char * pMem)
    *(pf+(127*3))=0xff;*pf++=0xff;
    pf+=127*3;
   }
-
+*/
 }
 
 ////////////////////////////////////////////////////////////////////////
 
 void CALLBACK GPUshowScreenPic(unsigned char * pMem)
 {
- DestroyPic();
- if(pMem==0) return;
- CreatePic(pMem);
+ //DestroyPic();
+ //if(pMem==0) return;
+ //CreatePic(pMem);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -3170,7 +3250,7 @@ void CALLBACK GPUvisualVibration(uint32_t iSmall, uint32_t iBig)
 
 void CALLBACK GPUdisplayFlags(uint32_t dwFlags)
 {
- dwCoreFlags=dwFlags;
+ //dwCoreFlags=dwFlags;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
